;;;;;;;;;;;;;;;;;;;;;; VARIABLES ;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

breed [oligarchs oligarch]
breed [parties party]
breed [voters voter]

oligarchs-own
[
  gross-income
  donation-size ; fraction of gross-income donated, if OLIGARCH-DONATION-VARIES
  donation-probability ; probability of donating, if not OLIGARCH-DONATION-VARIES
  
  last-donation ; from the previous cycle. donation-size if OLIGARCH-DONATION-VARIES, else donation-probability
  donation ; from this cycle. donation-size if OLIGARCH-DONATION-VARIES, else donation-probability
  last-subsidy ; from the previous cycle. the oligarch's share of the tax collected.
  subsidy ; from this previous cycle. the oligarch's share of the tax collected.
  has-memory ; true if last-subsidy and subsidy have been set in the "redistribute" procedure.
]

voters-own
[
  ideo ; position in the "ideological" dimension
  olig-salience ; salience, in [0, 1], of the "oligarchy" dimension. 1 - olig-salience = salience in the ideological dimension.
]

parties-own
[ 
  is-incumbent ; true if the Party won the previous election.
  previous-cycle-votes ; number of votes won in the previous election.
  ideo ; position in the "ideological" dimension
  olig ; position in the "oligarchy" dimension
  
  votes-increased ; true if the Party won more votes in this election than in the previous election
  olig-increased ; true if the Party's "olig" position increased in this cycle
  ideo-increased ; true if the Party's "ideo" position increased in this cycle
]

globals
[
 VOTER-COUNT ; number of voters
 OLIGARCH-COUNT ; number of oligarchs
  ; the model always has 2 Parties, so no PARTY-COUNT variable is used
 
 OLIGARCH-DONATION-VARIES ; if true, Oligarchs change what fraction of their gross-income, donation-size, they donate, but always donate.
 ; if false, Oligarchs only donate OLIGARCH-RATE of their gross-income, but they donate with variable probability, donation-probability.
 OLIGARCH-GDP-FRACTION ; what fraction of the gross-income of all agents is earned by the Oligarchs, as opposed to the Voters.
 OLIGARCH-INITIAL-DONATIONS-RANDOM ; if true, Oligarchs' initial donation-size or donation-probability is randomly selected, up to OLIGARCH-INITIAL-DONATION.
 ; if false, Oligarchs' initial donation-size or donation-probability is exactly OLIGARCH-INITIAL-DONATION
 ;OLIGARCH-INITIAL-DONATION ; see description of OLIGARCH-INITIAL-DONATIONS-RANDOM
 OLIGARCH-LATENCY ; how often (in run cycles) Oligarchs can alter their donation-size or donation-probability. to allow the results of an adjustment to this
 ; value to have an effect before the Oligarch readjusts, OLIGARCH-LATENCY should be set to about 10 or more cycles.
 OLIGARCH-EPSILON ; the size of a "step," or adjustment to donation-size or donation-probability.
 OLIGARCH-RATE ; the fraction of gross-income Oligarchs donate, if not OLIGARCH-DONATION-VARIES
 OLIGARCH-NOISE ; the probability that Oligarchs will update their donation-size or donation-probability in the opposite direction to that dictated by their
 ; strategy. This noise parameter helps Oligarchs to explore alternative strategies. It represents a "trembling hand" model of agent strategy adaptation.
 
 VOTER-MAX-TAX ; the maximum tax rate that can be assessed to Voters
 VOTER-OLIG ; position in the "oligarchy" dimension of Voters. All Voters have the same position, at the "anti-subsidy" extreme.
 VOTER-GROSS-INCOME ; the gross income of each Voter. Gross incomes are modeled as equal for all Voters.
 VOTER-AWARENESS ; affects the likelihood a Voter's olig-salience will increase in response to a tax assessed to the Voter.
 ; VOTER-MEMORY-STRENGTH ; affects the rate of decay of olig-salience in a Voter's "memory" after a Voter "notices" a tax they have to pay
 VOTER-MIN-DISTANCE-SCALE ; the minimum fraction of the actual distance from a Voter to a Party that the Voter can perceive, where the perceived distance
 ; is reduced by campaign spending by the Party.
 ; VOTER-AD-DECAY-FACTOR affects the rate of diminishing returns on marginal campaign spending by a Party, in terms of influence on a Voter's perceptions
 ; VOTER-INITIAL-SALIENCE ; initial olig-salience value of all Voters
 
 PARTY-EPSILON ; the size of a "step," or adjustment to a Party's ideo or olig position
 
 PARTY-DIFFERENCE-FACTOR ; affects Oligarchs' view of how important the difference in Parties' olig values is. If the Parties' olig values are more different,
 ; Oligarchs will donate more money to their preferred Party. The higher this factor, the more Oligarchs will tend to donate, and the more
 ; steeply donations will increase with increases in difference over a SMALL INITIAL difference in Parties' olig values.

 MIN-POS ; the minimum ideo or olig value
 MAX-POS ; the maximum ideo or olig value
 GDP ; the total number of units of gross income in the society, divided among Voters and Oligarchs
 
 voter-tax-rate ; the percent of gross-income paid in tax by Voters this cycle. Based on the incumbent Party's olig position.
 oligarch-recipient ; which Party received any donations from the Oligarchs. It is the Party with greater olig position.
 oligarch-total-donations ; the total donations paid by Oligarchs to their favored Party in this cycle. Based on each Oligarch's donation-size or
 ; donation-probability, and the difference in olig position between the Parties.
 
 total-tax-for-mean ; used to plot all-time average voter-tax-rate
 total-red-olig-for-mean ; used to plot all-time average of the red Party's olig value
 total-blue-olig-for-mean ; used to plot all-time average of the blue Party's olig value
 total-red-ideo-for-mean ; used to plot all-time average of the red Party's ideo value
 total-blue-ideo-for-mean ; used to plot all-time average of the blue Party's ideo value
 total-incumbent-olig-for-mean ; used to plot all-time average of the winning Party's olig value
 
 total-wins-red ; used to plot all-time win percentage for the red Party
 total-wins-blue ; used to plot all-time win percentage for the blue Party
 
 total-wins-olig-center ; used to plot all-time win percentage for the Party that is nearer 0 in ideo, and higher in olig
 total-wins-olig-not-center ; used to plot all-time win percentage for the Party that is farther from 0 in ideo, and higher in olig
 total-wins-not-olig-center ; used to plot all-time win percentage for the Party that is nearer 0 in ideo, and lower in olig
 
 total-mean-olig-salience-for-mean ; used to plot all-time average of mean Voter olig-salience
 total-olig-profit-for-mean ; used to plot all-time average of mean expected Oligarch profit (where profit = subsidy - expected campaign donation)
 total-donation-percent-for-mean ; used to plot all-time average of mean expected donation percentage of Oligarchs
 
 total-olig-difference-for-mean ; used to plot all-time average of difference in Parties' olig values
 total-ideo-difference-for-mean ; used to plot all-time average of difference in Parties' ideo values
 
 winner ; "B": winning Party is nearer 0 in ideo, and higher in olig. B is for "both"
 ; "O": winning Party is farther from 0 in ideo, and higher in olig. O is for "oligarchy"
 ; "M": winning Party is nearer 0 in ideo, and lower in olig. M is for "mean"
 ; "N": winning Party is farther from 0 in ideo, and lower in olig. N is for "neither"
 
 FIXED-PARTY-OLIG ; if true, Parties' olig values are fixed.
 FIXED-OLIG-DONATIONS ; if true, Oligarchs' donation-size or donation-probability is fixed.
 FIXED-DISTANCE-FACTOR ; if true, campaign donations have no effect on Voters' perceived distance to each Party.
 FIXED-VOTER-SALIENCE ; if true, Voters' olig-salience values are fixed.
 FIXED-TAX-RATE ; if true, the voter-tax-rate is fixed.

blue-party
red-party
]


;;;;;;;;;;;;;;;;;;;;;; MAIN METHODS ;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup-default
  clear-all
  reset-ticks
  setup-globals
  
  set OLIGARCH-INITIAL-DONATIONS-RANDOM true ;***** don't set for setup-fixed-donation-size
  set OLIGARCH-INITIAL-DONATION 0.3 ;***** don't set for setup-fixed-donation-size
  
  set VOTER-MEMORY-STRENGTH 0.9 ;***** don't set for setup-fixed-memory
  
  set VOTER-AD-DECAY-FACTOR -0.03 ;***** don't set for setup-fixed-ad-decay
  
  set VOTER-INITIAL-SALIENCE 0 ;***** don't set for setup-fixed-salience
  
  setup-display
  initialize-agents
end

to setup-fixed-party-olig
  clear-all
  reset-ticks
  setup-globals
  set FIXED-PARTY-OLIG true
  
  set OLIGARCH-INITIAL-DONATIONS-RANDOM true ;***** don't set for setup-fixed-donation-size
  set OLIGARCH-INITIAL-DONATION 0.3 ;***** don't set for setup-fixed-donation-size
  
  set VOTER-MEMORY-STRENGTH 0.9 ;***** don't set for setup-fixed-memory
  
  set VOTER-AD-DECAY-FACTOR -0.03 ;***** don't set for setup-fixed-ad-decay
  
  set VOTER-INITIAL-SALIENCE 0 ;***** don't set for setup-fixed-salience
  
  setup-display
  initialize-agents
end

to setup-fixed-donation-size
  clear-all
  reset-ticks
  setup-globals
  set FIXED-OLIG-DONATIONS true
  set OLIGARCH-INITIAL-DONATIONS-RANDOM false
  
  set VOTER-MEMORY-STRENGTH 0.9 ;***** don't set for setup-fixed-memory
  
  set VOTER-AD-DECAY-FACTOR -0.03 ;***** don't set for setup-fixed-ad-decay
  
  set VOTER-INITIAL-SALIENCE 0 ;***** don't set for setup-fixed-salience
  
  setup-display
  initialize-agents
end

to setup-fixed-ad-decay
  clear-all
  reset-ticks
  setup-globals
  
  set OLIGARCH-INITIAL-DONATIONS-RANDOM true ;***** don't set for setup-fixed-donation-size
  set OLIGARCH-INITIAL-DONATION 0.3 ;***** don't set for setup-fixed-donation-size
  
  set VOTER-MEMORY-STRENGTH 0.9 ;***** don't set for setup-fixed-memory
  
  set VOTER-INITIAL-SALIENCE 0 ;***** don't set for setup-fixed-salience
  
  setup-display
  initialize-agents
end

to setup-fixed-memory
  clear-all
  reset-ticks
  setup-globals
  
  set OLIGARCH-INITIAL-DONATIONS-RANDOM true ;***** don't set for setup-fixed-donation-size
  set OLIGARCH-INITIAL-DONATION 0.3 ;***** don't set for setup-fixed-donation-size
  
  set VOTER-AD-DECAY-FACTOR -0.03 ;***** don't set for setup-fixed-ad-decay
  
  set VOTER-INITIAL-SALIENCE 0 ;***** don't set for setup-fixed-salience
  
  setup-display
  initialize-agents
end

to setup-fixed-salience
  clear-all
  reset-ticks
  setup-globals
  set FIXED-VOTER-SALIENCE true
  
  set OLIGARCH-INITIAL-DONATIONS-RANDOM true ;***** don't set for setup-fixed-donation-size
  set OLIGARCH-INITIAL-DONATION 0.3 ;***** don't set for setup-fixed-donation-size
  
  set VOTER-MEMORY-STRENGTH 0.9 ;***** don't set for setup-fixed-memory
  
  set VOTER-AD-DECAY-FACTOR -0.03 ;***** don't set for setup-fixed-ad-decay
  
  setup-display
  initialize-agents
end

to go
  update-oligarch-donations
  vote
  redistribute
  update-voter-olig-salience
  update-party-policies
  do-plot
  tick
end


;;;;;;;;;;;;;;;;;;;;;; SETUP ;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup-globals
  set GDP 1000
  set MIN-POS -100
  set MAX-POS 100
  
  ; values of counts to try:
  ; VOTER-COUNT    OLIGARCH-COUNT    OLIGARCH-GDP-FRACTION
  ; 100            5                 0.05                      (default model)
  ; 50             5                 0.05
  ; 100            10                0.05
  ; 100            50                0.05
  ; 100            5                 0.02
  ; 100            5                 0.1
  set VOTER-COUNT 100
  set OLIGARCH-COUNT 5
  set OLIGARCH-GDP-FRACTION 0.05
  set OLIGARCH-LATENCY 10
  set PARTY-DIFFERENCE-FACTOR -2
  
  set OLIGARCH-EPSILON 0.1
  set OLIGARCH-RATE 0.5
  set OLIGARCH-NOISE 0.1
  set OLIGARCH-DONATION-VARIES true
  
  set VOTER-MAX-TAX 0.5
  set VOTER-OLIG MIN-POS
  set VOTER-GROSS-INCOME (GDP * (1 - OLIGARCH-GDP-FRACTION)) / VOTER-COUNT
  set VOTER-AWARENESS 0.5
  set VOTER-MIN-DISTANCE-SCALE 0.3
  
;  set OLIGARCH-INITIAL-DONATIONS-RANDOM true ;***** don't set for setup-fixed-donation-size
;  set OLIGARCH-INITIAL-DONATION 0.3 ;***** don't set for setup-fixed-donation-size
  
;  set VOTER-MEMORY-STRENGTH 0.9 ;***** don't set for setup-fixed-memory
  
;  set VOTER-AD-DECAY-FACTOR -0.03 ;***** don't set for setup-fixed-ad-decay
  
;  set VOTER-INITIAL-SALIENCE 0 ;***** don't set for setup-fixed-salience
  
  set PARTY-EPSILON 5
  
  ; this parameter's initial value does not matter if not FIXED-TAX-RATE, because it will be
  ; overwritten before being used. So there is no "default" value for voter-tax-rate.
  ; if FIXED-TAX-RATE, the initial value determines the voter-tax-rate for all time.
  set voter-tax-rate 0
  
  ; the default value for all of the "FIXED-" variables is false.
  set FIXED-PARTY-OLIG false
  set FIXED-OLIG-DONATIONS false
  set FIXED-DISTANCE-FACTOR false
  set FIXED-VOTER-SALIENCE false
  set FIXED-TAX-RATE false
end

to setup-display
  ask patches with [pycor <= MAX-POS]
  [set pcolor white]
  ask patches with [pycor > MAX-POS]
  [set pcolor gray + 1]
  
  set-default-shape oligarchs "circle"
  set-default-shape voters "circle"
  set-default-shape parties "square"
  
  set-current-plot "Olig Salience Histogram"
  set-plot-x-range 0 1
  set-histogram-num-bars 25
  
  set-current-plot "Donation Fraction Histogram"
  set-plot-x-range 0 1
  set-histogram-num-bars 25
end

to initialize-agents
  initialize-oligarchs
  initialize-parties
  initialize-voters
end

to initialize-oligarchs
  ; for lognormal distribution of oligarch incomes, if more than 1 oligarch
  let myMean GDP * OLIGARCH-GDP-FRACTION / OLIGARCH-COUNT
  let mySD GDP * OLIGARCH-GDP-FRACTION / (OLIGARCH-COUNT * 2)
  let myVar mySD * mySD
  ; mu = ln(mean^2 / (sqrt (variance + mean^2)))
  let mu ln(myMean * myMean / (sqrt (myVar + myMean * myMean)))
  ; sigma = sqrt(ln(1 + variance / mean^2))
  let sigma sqrt(ln(1 + myVar / (myMean * myMean)))
  
  let oligarch-ycor MAX-POS * 1.5
  let oligarch-spacing MAX-POS * 2.0 / (OLIGARCH-COUNT + 1)
  create-oligarchs OLIGARCH-COUNT
  [
    set size 10
    set color black
    let mywho who
    setxy (MIN-POS + (count oligarchs with [who <= mywho]) * oligarch-spacing) oligarch-ycor
    
    ifelse OLIGARCH-COUNT = 1
    [set gross-income GDP * OLIGARCH-GDP-FRACTION]
    [set gross-income random-lognormal mu sigma]

    set last-subsidy 0
    set subsidy 0
    set has-memory false
    
    ifelse OLIGARCH-DONATION-VARIES
    [
      ifelse OLIGARCH-INITIAL-DONATIONS-RANDOM
      [set donation-size random-float OLIGARCH-INITIAL-DONATION]
      [set donation-size OLIGARCH-INITIAL-DONATION]
    ]
    [
      ifelse OLIGARCH-INITIAL-DONATIONS-RANDOM
      [set donation-probability random-float OLIGARCH-INITIAL-DONATION]
      [set donation-probability OLIGARCH-INITIAL-DONATION]
    ]
  ]
  
  let mean-oligarch-income mean [gross-income] of oligarchs
  let target-mean GDP * OLIGARCH-GDP-FRACTION / OLIGARCH-COUNT
  ask oligarchs
  [set gross-income gross-income - (mean-oligarch-income - target-mean)]
  while [any? oligarchs with [gross-income <= 0]]
  [
    ask oligarchs
    [set gross-income random-lognormal mu sigma]
    set mean-oligarch-income mean [gross-income] of oligarchs
    ask oligarchs
    [set gross-income gross-income - (mean-oligarch-income - target-mean)]
  ]
end

to initialize-parties
  create-parties 2
  [ 
    set ideo random-normal 0 (MAX-POS / 3)
    while [ideo < MIN-POS or ideo > MAX-POS]
    [set ideo random-normal 0 (MAX-POS / 3)]
    
    set olig random-normal 0 (MAX-POS / 3)
    while [olig < MIN-POS or olig > MAX-POS]
    [set olig random-normal 0 (MAX-POS / 3)]
    
    set is-incumbent false
    party-update-displayed-position
    set size 15
    set label-color black
  ]
  
  ask min-one-of parties [who]
  [set color red]
  ask max-one-of parties [who]
  [set color blue]
  
  set red-party one-of parties with [color = red]
  set blue-party one-of parties with [color = blue]
end

to initialize-voters
  create-voters VOTER-COUNT
  [
    set ideo random-normal 0 (MAX-POS / 3)
    while [ideo < MIN-POS or ideo > MAX-POS]
    [set ideo random-normal 0 (MAX-POS / 3)]
    
    set olig-salience VOTER-INITIAL-SALIENCE
    set color green
    set size 5
    voter-update-displayed-position
  ]
end

to initialize-voters-bimodal
  create-voters VOTER-COUNT
  [
    ;; mixture of normal distributions:
    ;; mean A = 28.868, s.d. A = 100/6, mean B = -28.868, s.d. B = 100/6, mixture parameter = 0.5
    ;; overall mean = 0, overall s.d. = 100/3, which is the same as before.
    ;; variance = 0.5 (28.868^2 + 16.667^2) +  0.5 (28.868^2 + 16.667^2) = same as unimodal distribution's variance, 1111.111
    let mu 28.868
    let sd 100 / 6
    ifelse random-float 1 < 0.5
    [
      set ideo random-normal mu sd
      while [ideo < MIN-POS or ideo > MAX-POS]
      [set ideo random-normal mu sd]
    ]
    [
      set ideo random-normal (-1 * mu) sd
      while [ideo < MIN-POS or ideo > MAX-POS]
      [set ideo random-normal (-1 * mu) sd]
    ]

    
    set olig-salience VOTER-INITIAL-SALIENCE
    set color green
    set size 5
    voter-update-displayed-position
  ]
end

to-report random-lognormal [mu sigma]
  let z random-normal 0 1
  report exp (mu + sigma * z)
end

to party-update-displayed-position
  setxy ideo olig
  
  ; highlight the incumbent Party by giving it the "square 2" shape
  ifelse is-incumbent
  [set shape "square 2"]
  [set shape "square"]
  
  set size 5 + 30 * previous-cycle-votes / VOTER-COUNT
end

to voter-update-displayed-position
  let y VOTER-OLIG
  if y = MIN-POS
  [set y y + 2.5]
  setxy ideo y
end


;;;;;;;;;;;;;;;;;;;;;; GO ;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to update-oligarch-donations
  let total-donations 0
  ask oligarchs
  [
    ; Oligarchs only alter their donation-size or donation-probability every OLIGARCH-LATENCY ticks,
    ; and they do so in staggered run cycles, so that Oligarchs will not tend to converge on the same
    ; parameters across all Oligarchs.
    if (not FIXED-OLIG-DONATIONS) and (ticks + who) mod OLIGARCH-LATENCY = 0
    [
      ifelse has-memory
      [
        ; recall: donation = donation-size if OLIGARCH-DONATION-VARIES, else donation-probability.
        ; last-donation is donation from the previous cycle.
        let donation-increase donation - last-donation
        let did-expected-donation-increase (donation-increase > 0)
        
        let expected-donation-increase 0
        ifelse OLIGARCH-DONATION-VARIES
        [
          ; actual amount donated is donation-size * gross-income * party-olig-difference-scaled,
          ; so the change in donation-size (donation-increase) * gross-income * party-olig-difference-scaled is the expected donation increase.
          set expected-donation-increase donation-increase * gross-income * party-olig-difference-scaled
        ]
        [
          ; expected amount donated is donation-probability * OLIGARCH-RATE * gross-income * party-olig-difference-scaled,
          ; so the change in donation-probability (donation-increase) * OLIGARCH-RATE * gross-income * party-olig-difference-scaled is the
          ; expected donation increase.
          set expected-donation-increase donation-increase * gross-income * party-olig-difference-scaled * OLIGARCH-RATE
        ]
        
        let subsidy-increase subsidy - last-subsidy
        
        let did-expected-profit-increase (subsidy-increase - expected-donation-increase) > 0
        let increase (did-expected-donation-increase = did-expected-profit-increase)
        if donation-increase = 0 and subsidy-increase = 0
        [set increase false]
        
        if random-float 1 < OLIGARCH-NOISE ; "trembling hand" effect
        [set increase not increase]
        
        oligarch-change-donation increase
      ]
      [
        ; no memory of past runs, so pick a random direction to move.
        let increase false
        if random-float 1 < 0.5
        [set increase true]
        
        oligarch-change-donation increase
      ]
    ]
    
    ifelse OLIGARCH-DONATION-VARIES
    [
      set total-donations total-donations + gross-income * donation-size * party-olig-difference-scaled
      set size 5 + 50 * gross-income * donation-size / (GDP * OLIGARCH-GDP-FRACTION)
      set label precision donation-size 2
    ]
    [
      if random-float 1 < donation-probability
      [set total-donations total-donations + gross-income * OLIGARCH-RATE * party-olig-difference-scaled]
      
      set size 5 + 50 * gross-income * donation-probability / (GDP * OLIGARCH-GDP-FRACTION)
      set label precision donation-probability 2
    ]
  ]
  
  set oligarch-recipient max-one-of parties [olig]
  ask oligarchs
  [set color [color] of oligarch-recipient]
  set oligarch-total-donations total-donations
  
  ifelse OLIGARCH-DONATION-VARIES
  [set total-donation-percent-for-mean total-donation-percent-for-mean + mean [donation-size] of oligarchs * party-olig-difference-scaled]
  [set total-donation-percent-for-mean total-donation-percent-for-mean + mean [donation-probability] of oligarchs * OLIGARCH-RATE * party-olig-difference-scaled]
end

to vote
  let party-red one-of parties with [color = red]
  let party-blue one-of parties with [color = blue]
  let red-votes 0
  let blue-votes 0
  ask voters
  [
    let party-red-dist voter-distance party-red
    let party-blue-dist voter-distance party-blue
    
    ifelse party-red-dist < party-blue-dist
    [
      set red-votes red-votes + 1
      set color red
    ]
    [
      ifelse party-red-dist > party-blue-dist
      [
        set blue-votes blue-votes + 1
        set color blue
      ]
      [
        ifelse random-float 1 < 0.5
        [
          set red-votes red-votes + 1
          set color red
        ]
        [
          set blue-votes blue-votes + 1
          set color blue
        ]
      ]
    ]
  ]
  
  ask party-red
  [party-update-votes red-votes]
  ask party-blue
  [party-update-votes blue-votes]
  
  ifelse red-votes > blue-votes
  [set-winner-red true]
  [
    ifelse red-votes < blue-votes
    [set-winner-red false]
    [set-winner-red random-float 1 < 0.5]
  ]
  
  let winning-party one-of parties with [is-incumbent]
  let losing-party one-of parties with [not is-incumbent]
  ask winning-party
  [set total-incumbent-olig-for-mean total-incumbent-olig-for-mean + olig]
  
  ifelse [abs xcor] of winning-party < [abs xcor] of losing-party
  [
    ; center won
    ifelse [ycor] of winning-party > [ycor] of losing-party
    [
      ; olig won
      set total-wins-olig-center total-wins-olig-center + 1
      set winner "B" ; both oligarchs and mean voter won
    ]
    [
      ; olig lost
      set total-wins-not-olig-center total-wins-not-olig-center + 1
      set winner "M" ; mean voter won but not oligarchs
    ]
  ]
  [
    ifelse [ycor] of winning-party > [ycor] of losing-party
    [
      ; olig won
      set total-wins-olig-not-center total-wins-olig-not-center + 1
      set winner "O" ; oligarchs won but not mean voter
    ]
    [set winner "N"] ; neither oligarchs nor mean voter won
  ]
end

to redistribute
  let party-a min-one-of parties [who]
  let party-b max-one-of parties [who]
  
  let incumbent-olig [olig] of one-of parties with [is-incumbent]
  if not FIXED-TAX-RATE
  [set voter-tax-rate (VOTER-MAX-TAX / 2) * (1 + incumbent-olig / MAX-POS)]

  set total-tax-for-mean total-tax-for-mean + voter-tax-rate
  
  let tax-collected voter-tax-rate * VOTER-COUNT * VOTER-GROSS-INCOME
  ask oligarchs
  [
    if (ticks + who) mod OLIGARCH-LATENCY = 0
    [
      set last-subsidy subsidy
      set subsidy tax-collected * gross-income / (GDP * OLIGARCH-GDP-FRACTION)
      set has-memory true
    ]
  ]
  
  ifelse OLIGARCH-DONATION-VARIES
  [set total-olig-profit-for-mean total-olig-profit-for-mean + mean [subsidy - donation * party-olig-difference-scaled] of oligarchs]
  [set total-olig-profit-for-mean total-olig-profit-for-mean + mean [subsidy - donation * OLIGARCH-RATE * party-olig-difference-scaled] of oligarchs]
end

to update-voter-olig-salience
  if not FIXED-VOTER-SALIENCE
  [
    ask voters
    [
      ifelse random-float 1 < voter-tax-rate ^ VOTER-AWARENESS
      [
        let headroom voter-tax-rate - olig-salience * VOTER-MEMORY-STRENGTH
        if headroom < 0
        [set headroom 0]
        set olig-salience olig-salience * VOTER-MEMORY-STRENGTH + random-float headroom
      ]
      [set olig-salience olig-salience * VOTER-MEMORY-STRENGTH]
    ]
  ]
  
  set total-mean-olig-salience-for-mean total-mean-olig-salience-for-mean + mean [olig-salience] of voters
end

to update-party-policies
  ask parties
  [
    let should-increase-olig false
    let should-increase-ideo false
    
    ifelse olig-increased != 0
    [ 
      ; olig-increased has been set to a boolean value
      ifelse votes-increased
      [
        set should-increase-olig olig-increased
        set should-increase-ideo ideo-increased
        set label "+"
      ]
      [
        let draw random 4
        ifelse draw = 0 or draw = 1
        [
          set should-increase-olig not olig-increased
          set should-increase-ideo not ideo-increased
        ]
        [
          ifelse draw = 2
          [
            set should-increase-olig not olig-increased
            set should-increase-ideo ideo-increased
          ]
          [
            ; draw = 3
            set should-increase-olig olig-increased
            set should-increase-ideo not ideo-increased
          ]
        ]

        set label "-"
      ]
    ]
    [
      set should-increase-olig random-float 1 < 0.5
      set should-increase-ideo random-float 1 < 0.5
      set label ""
    ]
    
    ifelse should-increase-olig
    [party-adjust-variable true false] ; increase olig
    [party-adjust-variable false false] ; decrease olig
      
    ifelse should-increase-ideo
    [party-adjust-variable true true] ; increase ideo
    [party-adjust-variable false true] ; decrease ideo
    
    set olig-increased should-increase-olig
    set ideo-increased should-increase-ideo

    if color = red
    [
      set total-red-olig-for-mean total-red-olig-for-mean + olig
      set total-red-ideo-for-mean total-red-ideo-for-mean + ideo
    ]
    if color = blue
    [
      set total-blue-olig-for-mean total-blue-olig-for-mean + olig
      set total-blue-ideo-for-mean total-blue-ideo-for-mean + ideo
    ]
    
    party-update-displayed-position
  ]
  
  set total-olig-difference-for-mean total-olig-difference-for-mean + party-difference true ; difference in olig between Parties
  set total-ideo-difference-for-mean total-ideo-difference-for-mean + party-difference false ; difference in ideo between Parties
end

to-report party-difference [is-olig]
  let result 0
  ifelse is-olig
  [set result (max [olig] of parties - min [olig] of parties) / (MAX-POS - MIN-POS)]
  [set result (max [ideo] of parties - min [ideo] of parties) / (MAX-POS - MIN-POS)]
  report result
end

to set-winner-red [is-red-winner]
  let party-red one-of parties with [color = red]
  let party-blue one-of parties with [color = blue]
  
  ask party-red
  [set is-incumbent is-red-winner]
  ask party-blue
  [set is-incumbent not is-red-winner]
  
  ifelse is-red-winner
  [set total-wins-red total-wins-red + 1]
  [set total-wins-blue total-wins-blue + 1]
end

to party-adjust-variable [is-increase is-ideo]
  ifelse is-ideo
  [
    ; adjust ideo
    ifelse is-increase
    [
      set ideo ideo + PARTY-EPSILON
      if ideo > MAX-POS
      [set ideo MAX-POS]
    ]
    [
      set ideo ideo - PARTY-EPSILON
      if ideo < MIN-POS
      [set ideo MIN-POS]
    ]
  ]
  [
    ; adjust olig
    if not FIXED-PARTY-OLIG
    [
      ifelse is-increase
      [
        set olig olig + PARTY-EPSILON
        if olig > MAX-POS
        [set olig MAX-POS]
      ]
      [
        set olig olig - PARTY-EPSILON
        if olig < MIN-POS
        [set olig MIN-POS]
      ]
    ]
  ]
end

to-report party-olig-difference-scaled
  report 1 - exp (PARTY-DIFFERENCE-FACTOR * party-olig-difference)
end

to-report party-olig-difference
  report (max [olig] of parties - min [olig] of parties) / (MAX-POS - MIN-POS)
end

to oligarch-change-donation [increase]
  set last-donation donation
  
  ifelse OLIGARCH-DONATION-VARIES
  [
    ifelse increase
    [
      set donation-size donation-size + OLIGARCH-EPSILON
      if donation-size > 1
      [set donation-size 1]
    ]
    [
      set donation-size donation-size - OLIGARCH-EPSILON
      if donation-size < 0
      [set donation-size 0]
    ]
    set donation donation-size
  ]
  [
    ifelse increase
    [
      set donation-probability donation-probability + OLIGARCH-EPSILON
      if donation-probability > 1
      [set donation-probability 1]
    ]
    [
      set donation-probability donation-probability - OLIGARCH-EPSILON
      if donation-probability < 0
      [set donation-probability 0]
    ]
    set donation donation-probability
  ]
end

to party-update-votes [votes]
  set votes-increased (votes > previous-cycle-votes)
  set previous-cycle-votes votes
end

to-report voter-distance [a-party]
  let ideo-distance abs (ideo - [ideo] of a-party)
  let olig-distance abs (VOTER-OLIG - [olig] of a-party)
  let absolute-distance-with-salience ideo-distance * (1 - olig-salience) + olig-distance * olig-salience
  let scale-factor 1
  if (not FIXED-DISTANCE-FACTOR) AND oligarch-recipient = a-party
  [
    set scale-factor get-scale-exponential
    ; set scale-factor get-scale-linear
  ]
  report scale-factor * absolute-distance-with-salience
end

to-report get-scale-exponential
  report VOTER-MIN-DISTANCE-SCALE + (1 - VOTER-MIN-DISTANCE-SCALE) * exp (VOTER-AD-DECAY-FACTOR * oligarch-total-donations)
end

to-report get-scale-linear
  report 1 - (1 - VOTER-MIN-DISTANCE-SCALE) * (oligarch-total-donations / (GDP * OLIGARCH-GDP-FRACTION))
end


;;;;;;;;;;;;;;;;;;;;;; GRAPHING ;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to do-plot
  set-current-plot "Tax Rate"
  set-current-plot-pen "current"
  plot voter-tax-rate
  set-current-plot-pen "max"
  plot VOTER-MAX-TAX
  set-current-plot-pen "mean"
  plot total-tax-for-mean / (ticks + 1)
  
  set-current-plot "Win Fraction"
  set-current-plot-pen "blue"
  plot total-wins-blue / (ticks + 1)
  set-current-plot-pen "red"
  plot total-wins-red / (ticks + 1)
  
  set-current-plot "Party Olig Position"
  set-current-plot-pen "blue"
  plot [olig] of one-of parties with [color = blue]
  set-current-plot-pen "blue-mean"
  plot total-blue-olig-for-mean / (ticks + 1)
  set-current-plot-pen "red"
  plot [olig] of one-of parties with [color = red]
  set-current-plot-pen "red-mean"
  plot total-red-olig-for-mean / (ticks + 1)
  set-current-plot-pen "incumbent-mean"
  plot total-incumbent-olig-for-mean / (ticks + 1)
  
  set-current-plot "Donation Fraction"
  set-current-plot-pen "current"
  ifelse OLIGARCH-DONATION-VARIES
  [plot mean [donation-size * party-olig-difference-scaled] of oligarchs]
  [plot mean [donation-probability * party-olig-difference-scaled] of oligarchs]
  set-current-plot-pen "mean"
  plot total-donation-percent-for-mean / (ticks + 1)
  
  set-current-plot "Party Ideo Position"
  set-current-plot-pen "blue"
  plot [ideo] of one-of parties with [color = blue]
  set-current-plot-pen "blue-mean"
  plot total-blue-ideo-for-mean / (ticks + 1)
  set-current-plot-pen "red"
  plot [ideo] of one-of parties with [color = red]
  set-current-plot-pen "red-mean"
  plot total-red-ideo-for-mean / (ticks + 1)
  
  set-current-plot "Winning Constituency"
  set-current-plot-pen "olig-center"
  plot total-wins-olig-center / (ticks + 1)
  set-current-plot-pen "olig-not-center"
  plot total-wins-olig-not-center / (ticks + 1)
  set-current-plot-pen "not-olig-center"
  plot total-wins-not-olig-center / (ticks + 1)
  
  set-current-plot "Voter Olig Salience"
  set-current-plot-pen "current"
  plot mean [olig-salience] of voters
  set-current-plot-pen "mean"
  plot total-mean-olig-salience-for-mean / (ticks + 1)
  set-current-plot-pen "min"
  plot min [olig-salience] of voters
  set-current-plot-pen "max"
  plot max [olig-salience] of voters
  
  set-current-plot "Oligarch Profit"
  set-current-plot-pen "current"
  plot mean [subsidy - donation * party-olig-difference-scaled * gross-income] of oligarchs
  set-current-plot-pen "zero"
  plot 0
  set-current-plot-pen "mean"
  plot total-olig-profit-for-mean / (ticks + 1)
  
  set-current-plot "Olig Salience Histogram"
  set-current-plot-pen "current"
  histogram [olig-salience] of voters
  
  set-current-plot "Donation Fraction Histogram"
  set-current-plot-pen "current"
  ifelse OLIGARCH-DONATION-VARIES
  [histogram [donation-size * party-olig-difference-scaled] of oligarchs]
  [histogram [donation-probability * party-olig-difference-scaled] of oligarchs]
  
  set-current-plot "Party Olig Difference"
  set-current-plot-pen "current"
  plot party-difference true ; difference in olig between Parties
  set-current-plot-pen "mean"
  plot total-olig-difference-for-mean / (ticks + 1)
  
  set-current-plot "Party Ideo Difference"
  set-current-plot-pen "current"
  plot party-difference false ; difference in ideo between Parties
  set-current-plot-pen "mean"
  plot total-ideo-difference-for-mean / (ticks + 1)
end
@#$#@#$#@
GRAPHICS-WINDOW
224
10
636
643
100
-1
2.0
1
12
1
1
1
0
0
0
1
-100
100
-100
200
0
0
1
ticks
30.0

BUTTON
6
10
122
43
NIL
setup-default
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
6
47
72
80
go-once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
6
85
93
118
go-forever
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
648
10
941
186
Tax Rate
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"current" 1.0 0 -7500403 true "" ""
"max" 1.0 0 -7500403 true "" ""
"mean" 1.0 0 -16777216 true "" ""

PLOT
648
190
941
365
Party Olig Position
NIL
NIL
0.0
10.0
-100.0
100.0
true
false
"" ""
PENS
"blue" 1.0 0 -13345367 true "" ""
"red" 1.0 0 -2674135 true "" ""
"blue-mean" 1.0 0 -8020277 true "" ""
"red-mean" 1.0 0 -1604481 true "" ""
"incumbent-mean" 1.0 0 -9276814 true "" ""

PLOT
648
370
941
542
Party Ideo Position
NIL
NIL
0.0
10.0
-100.0
100.0
true
false
"" ""
PENS
"blue" 1.0 0 -13345367 true "" ""
"red" 1.0 0 -2674135 true "" ""
"blue-mean" 1.0 0 -8020277 true "" ""
"red-mean" 1.0 0 -1604481 true "" ""

PLOT
946
10
1228
186
Win Fraction
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"blue" 1.0 0 -13345367 true "" ""
"red" 1.0 0 -2674135 true "" ""

PLOT
946
190
1228
365
Donation Fraction
NIL
NIL
0.0
10.0
0.0
0.5
true
false
"" ""
PENS
"current" 1.0 0 -7500403 true "" ""
"mean" 1.0 0 -16777216 true "" ""

PLOT
946
370
1228
542
Winning Constituency
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"olig-center" 1.0 0 -10899396 true "" ""
"olig-not-center" 1.0 0 -2674135 true "" ""
"not-olig-center" 1.0 0 -4079321 true "" ""

PLOT
648
547
941
703
Voter Olig Salience
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"current" 1.0 0 -7500403 true "" ""
"mean" 1.0 0 -16777216 true "" ""
"min" 1.0 0 -7500403 true "" ""
"max" 1.0 0 -7500403 true "" ""

PLOT
946
547
1228
703
Oligarch Profit
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"current" 1.0 0 -7500403 true "" ""
"zero" 1.0 0 -4539718 true "" ""
"mean" 1.0 0 -16777216 true "" ""

PLOT
6
121
222
262
Olig Salience Histogram
NIL
NIL
0.0
1.0
0.0
10.0
true
false
"" ""
PENS
"current" 1.0 1 -16777216 true "" ""

PLOT
6
266
222
416
Donation Fraction Histogram
NIL
NIL
0.0
1.0
0.0
10.0
true
false
"" ""
PENS
"current" 1.0 1 -16777216 true "" ""

PLOT
6
418
222
568
Party Olig Difference
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"current" 1.0 0 -7500403 true "" ""
"mean" 1.0 0 -16777216 true "" ""

PLOT
6
570
222
701
Party Ideo Difference
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"current" 1.0 0 -7500403 true "" ""
"mean" 1.0 0 -16777216 true "" ""

SLIDER
229
645
426
678
VOTER-MEMORY-STRENGTH
VOTER-MEMORY-STRENGTH
0.1
0.9
0.9
0.2
1
NIL
HORIZONTAL

SLIDER
431
645
637
678
OLIGARCH-INITIAL-DONATION
OLIGARCH-INITIAL-DONATION
0
1
0.3
0.2
1
NIL
HORIZONTAL

SLIDER
226
680
430
713
VOTER-AD-DECAY-FACTOR
VOTER-AD-DECAY-FACTOR
-0.12
-0.02
-0.03
0.02
1
NIL
HORIZONTAL

SLIDER
434
681
637
714
VOTER-INITIAL-SALIENCE
VOTER-INITIAL-SALIENCE
0
1
0
0.2
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="default-test" repetitions="100" runMetricsEveryStep="true">
    <setup>setup-default</setup>
    <go>go</go>
    <exitCondition>ticks = 1300</exitCondition>
    <metric>precision mean [olig] of parties 3</metric>
    <metric>precision mean [ideo] of parties 3</metric>
    <metric>precision (max [olig] of parties - min [olig] of parties) 3</metric>
    <metric>precision (max [ideo] of parties - min [ideo] of parties) 3</metric>
    <metric>precision voter-tax-rate 3</metric>
    <metric>precision mean [olig-salience] of voters 3</metric>
    <metric>precision mean [donation-size * party-olig-difference-scaled] of oligarchs 3</metric>
    <metric>precision ((voter-tax-rate * VOTER-COUNT * VOTER-GROSS-INCOME - (sum [donation-size * party-olig-difference-scaled * gross-income] of oligarchs)) / OLIGARCH-COUNT) 3</metric>
    <metric>precision [previous-cycle-votes] of red-party 3</metric>
    <metric>precision [previous-cycle-votes] of blue-party 3</metric>
    <metric>precision [ideo] of red-party 3</metric>
    <metric>precision [ideo] of blue-party 3</metric>
    <metric>precision [olig] of red-party 3</metric>
    <metric>precision [olig] of blue-party 3</metric>
  </experiment>
  <experiment name="fixed-olig" repetitions="100" runMetricsEveryStep="true">
    <setup>setup-fixed-party-olig</setup>
    <go>go</go>
    <exitCondition>ticks = 1300</exitCondition>
    <metric>precision mean [donation-size * party-olig-difference-scaled] of oligarchs 3</metric>
    <metric>precision mean [olig-salience] of voters 3</metric>
    <metric>precision ((voter-tax-rate * VOTER-COUNT * VOTER-GROSS-INCOME - (sum [donation-size * party-olig-difference-scaled * gross-income] of oligarchs)) / OLIGARCH-COUNT) 3</metric>
  </experiment>
  <experiment name="voter-memory-sweep" repetitions="20" runMetricsEveryStep="true">
    <setup>setup-fixed-memory</setup>
    <go>go</go>
    <exitCondition>ticks = 1300</exitCondition>
    <metric>precision voter-tax-rate 3</metric>
    <metric>precision mean [olig] of parties 3</metric>
    <metric>precision mean [olig-salience] of voters 3</metric>
    <metric>precision mean [donation-size * party-olig-difference-scaled] of oligarchs 3</metric>
    <metric>winner</metric>
    <metric>precision ((voter-tax-rate * VOTER-COUNT * VOTER-GROSS-INCOME - (sum [donation-size * party-olig-difference-scaled * gross-income] of oligarchs)) / OLIGARCH-COUNT) 3</metric>
    <steppedValueSet variable="VOTER-MEMORY-STRENGTH" first="0.1" step="0.2" last="0.9"/>
  </experiment>
  <experiment name="olig-donation-sweep" repetitions="20" runMetricsEveryStep="true">
    <setup>setup-fixed-donation-size</setup>
    <go>go</go>
    <exitCondition>ticks = 1300</exitCondition>
    <metric>precision voter-tax-rate 3</metric>
    <metric>precision mean [olig] of parties 3</metric>
    <metric>precision mean [olig-salience] of voters 3</metric>
    <metric>precision mean [donation-size * party-olig-difference-scaled] of oligarchs 3</metric>
    <metric>winner</metric>
    <metric>precision ((voter-tax-rate * VOTER-COUNT * VOTER-GROSS-INCOME - (sum [donation-size * party-olig-difference-scaled * gross-income] of oligarchs)) / OLIGARCH-COUNT) 3</metric>
    <steppedValueSet variable="OLIGARCH-INITIAL-DONATION" first="0" step="0.2" last="1"/>
  </experiment>
  <experiment name="ad-decay-sweep" repetitions="20" runMetricsEveryStep="true">
    <setup>setup-fixed-ad-decay</setup>
    <go>go</go>
    <exitCondition>ticks = 1300</exitCondition>
    <metric>precision voter-tax-rate 3</metric>
    <metric>precision mean [olig] of parties 3</metric>
    <metric>precision mean [olig-salience] of voters 3</metric>
    <metric>precision mean [donation-size * party-olig-difference-scaled] of oligarchs 3</metric>
    <metric>winner</metric>
    <metric>precision ((voter-tax-rate * VOTER-COUNT * VOTER-GROSS-INCOME - (sum [donation-size * party-olig-difference-scaled * gross-income] of oligarchs)) / OLIGARCH-COUNT) 3</metric>
    <steppedValueSet variable="VOTER-AD-DECAY-FACTOR" first="-0.12" step="0.02" last="-0.02"/>
  </experiment>
  <experiment name="voter-salience-sweep" repetitions="20" runMetricsEveryStep="true">
    <setup>setup-fixed-salience</setup>
    <go>go</go>
    <exitCondition>ticks = 1300</exitCondition>
    <metric>precision voter-tax-rate 3</metric>
    <metric>precision mean [olig] of parties 3</metric>
    <metric>precision abs mean [ideo] of parties 3</metric>
    <metric>precision mean [olig-salience] of voters 3</metric>
    <metric>precision mean [donation-size * party-olig-difference-scaled] of oligarchs 3</metric>
    <metric>winner</metric>
    <metric>precision ((voter-tax-rate * VOTER-COUNT * VOTER-GROSS-INCOME - (sum [donation-size * party-olig-difference-scaled * gross-income] of oligarchs)) / OLIGARCH-COUNT) 3</metric>
    <steppedValueSet variable="VOTER-INITIAL-SALIENCE" first="0" step="0.2" last="1"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
